@@ -1,5 +1,7 @@
 use interoptopus::ffi_type;
 use interoptopus::lang::c::{CType, CompositeType, Field, PrimitiveType};
+use interoptopus::lang::rust::CTypeInfo;
+use std::marker::PhantomData;
 
 // Let's assume we can't implement `CTypeInfo` for this.
 #[repr(C)]
@@ -23,6 +25,20 @@ pub struct Opaque {
     _internal: *const Vec3f32,
 }
 
+#[ffi_type]
+#[repr(C)]
+pub struct Generic<'a, T> where T: 'static, T: CTypeInfo {
+    pub x: &'a T,
+}
+
+#[ffi_type(skip(p))]
+#[repr(C)]
+pub struct Phantom<'a, T> where T: 'static, T: CTypeInfo {
+    pub x: u32,
+    pub p: PhantomData<&'a T>
+}
+
+
 #[ffi_type]
 #[repr(C)]
 pub struct Vec3f32 {
@@ -45,5 +61,25 @@ pub enum FFIError {
     Fail = 200,
 }
 
-// Don't need annotations.
+
+/// Documented enum.
+#[ffi_type]
+#[repr(C)]
+pub enum EnumDocumented {
+    /// Variant A.
+    A,
+    /// Variant B.
+    B,
+}
+
+/// Documented struct.
+#[ffi_type]
+#[repr(C)]
+pub struct StructDocumented {
+    /// Documented field.
+    pub x: f32,
+}
+
+
+// Doesn't need annotations.
 pub type Callback = extern "C" fn(u8) -> u8;
